@@ -1,10 +1,20 @@
 import subprocess
 import sys
-
+import os
 def install(package):
     subprocess.check_call([sys.executable, "-m", "pip", "install", package])
 
-install(".\\deepfake_detection\\pytorchcv-0.0.55-py2.py3-none-any.whl")
+
+__Packagelocation__ = os.path.realpath(os.path.join(os.getcwd(), os.path.dirname("pytorchcv-0.0.55-py2.py3-none-any.whl")))
+PackagePath = os.path.join(__Packagelocation__, "deepfake_detection","pytorchcv-0.0.55-py2.py3-none-any.whl")
+
+__Blazefacelocation__ = os.path.realpath(os.path.join(os.getcwd(), os.path.dirname("blazeface.pth")))
+BlazefacePath = os.path.join(__Blazefacelocation__, "deepfake_detection","blazeface.pth")
+
+__Anchorslocation__ = os.path.realpath(os.path.join(os.getcwd(), os.path.dirname("anchors.npy")))
+AnchorsPath = os.path.join(__Anchorslocation__, "deepfake_detection","anchors.npy")
+
+install(PackagePath)
 install("pytube")
 install("moviepy")
 install("youtube-dl")
@@ -999,8 +1009,8 @@ def overlap_similarity(box, other_boxes):
 
 #######################################################################
 facedet = BlazeFace().to(device)
-facedet.load_weights(".\\deepfake_detection\\blazeface.pth")
-facedet.load_anchors(".\\deepfake_detection\\anchors.npy")
+facedet.load_weights(BlazefacePath)
+facedet.load_anchors(AnchorsPath)
 _ = facedet.train(False)
 
 
